let
	hosts = (import ../lib/hosts.nix);
	removeNewlines = (import ../lib/util/remove-newlines.nix);
	presetRootSsh = (import ../lib/presets/root-ssh.nix);
in {
	osmium = {config, pkgs, ...}@args: let
		presetTools = (import ../lib/presets/tools.nix) args;
		presetQemuGuest = (import ../lib/presets/qemu-guest.nix);
	in
		{
			deployment.targetHost = hosts.osmium.ipv4;

			/* Begin hardware configuration section */
			boot.kernelModules = [ ];
			boot.extraModulePackages = [ ];
			swapDevices = [ ];
			nix.maxJobs = pkgs.lib.mkDefault 2;
			/* End hardware configuration section */

			systems.osmium = {
				applications.pastebin-stream = {
					hostname = "pastebin-stream.cryto.net";
				};
			};

			fileSystems = {
				"/" = {
					device = "/dev/disk/by-uuid/cf472470-0b3d-414b-93f8-b5e4298fad05";
					fsType = "ext4";
				};
			};

			networking = {
				hostName = "osmium";
				defaultGateway6 = "2a01:4a0:4a::1";
				interfaces.ens3 = {
					ipv6.addresses = [{
						address = "2a01:4a0:4a:5d::35c7";
						prefixLength = 48;
					}];
				};
			};
		} // presetRootSsh // presetTools // presetQemuGuest;
}
