let
	hosts = (import ../lib/hosts.nix);
	removeNewlines = (import ../lib/util/remove-newlines.nix);
	presetRootSsh = (import ../lib/presets/root-ssh.nix);
in {
	workbot = {config, pkgs, ...}@args: let
		presetTools = (import ../lib/presets/tools.nix) args;
	in
		{
			deployment.targetHost = hosts.workbot.ipv4;

			/* Begin hardware configuration section */
			boot.initrd.availableKernelModules = [ "xhci_pci" "ehci_pci" "ahci" "usbhid" "usb_storage" "sd_mod" "sr_mod" ];
			boot.kernelModules = [ "kvm-intel" ];
			boot.extraModulePackages = [ ];
			swapDevices = [ ];
			nix.maxJobs = pkgs.lib.mkDefault 8;
			powerManagement.cpuFreqGovernor = pkgs.lib.mkDefault "powersave";
			hardware.enableRedistributableFirmware = true;
			/* End hardware configuration section */

			boot.loader.grub = {
				enable = true;
				version = 2;
				device = "/dev/sda";
			};

			fileSystems = {
				"/" = {
					device = "/dev/disk/by-label/nix";
					fsType = "ext4";
				};
				"/boot" = {
					device = "/dev/disk/by-label/boot";
					fsType = "ext4";
				};
			};

			networking = {
				hostName = "workbot";
			};

			system.stateVersion = "18.03";
		} // presetRootSsh // presetTools;
}
